@@ -4,4 +4,8 @@
 from easydsi.linked_list import *
 from easydsi.array import *
 from easydsi.stack import *
-from easydsi.queue import *
\ No newline at end of file
+from easydsi.queue import *
+
+__version__ = "1.0.3"
+__developer__ = "Mohamed Fazil Z"
+__website__ = "https://github.com/fazil2003/easydsi"
\ No newline at end of file
