@@ -5,20 +5,23 @@ class Stack():
     def __init__(self, size, elements):
         self.size = size
         self.elements = elements
-        self.length = len(elements)
+        if(any(self.elements)):
+            self.length = len(elements)
+        else:
+            self.length = 0
     
     def index(self, position):
         return self.elements[position]
 
     def add(self, element):
-        if(self.size == len(self.elements)):
+        if(self.size == self.length):
             print("Stack is full")
         else:
             self.elements.append(element)
             self.length += 1
 
     def remove(self):
-        if(len(self.elements) == 0):
+        if(self.length == 0):
             print("Stack is empty")
         else:
             elementToReturn = self.elements.pop()
@@ -38,7 +41,7 @@ class Stack():
         return self.length
 
 
-def stack():
+def stack(size):
 
     if(isinstance(size, int)):
         elements = [0] * size
